#!/usr/bin/env python
# coding: utf-8

from .settings import VERSION


version_info = VERSION.split('.')

__version__ = VERSION
__project__ = PROJECT = __name__
__author__ = AUTHOR = "Kirill Klenov <horneds@gmail.com>"
__license__ = LICENSE = "GNU LGPL"
