/* ========== */
/* From: 'zeta:///zeta.css' */
/* Zeta import: 'zeta:///zeta/z-reset/z-reset.css' */
/* http://meyerweb.com/eric/tools/css/reset/ 
   v2.0 | 20110126
   License: none (public domain)
*/

html, body, div, span, applet, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
a, abbr, acronym, address, big, cite, code,
del, dfn, em, img, ins, kbd, q, s, samp,
small, strike, strong, sub, sup, tt, var,
b, u, i, center,
dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td,
article, aside, canvas, details, embed, 
figure, figcaption, footer, header, hgroup, 
menu, nav, output, ruby, section, summary,
time, mark, audio, video {
	margin: 0;
	padding: 0;
	border: 0;
	font-size: 100%;
	font: inherit;
	vertical-align: baseline;
}
/* HTML5 display-role reset for older browsers */
article, aside, details, figcaption, figure, 
footer, header, hgroup, menu, nav, section {
	display: block;
}
body {
	line-height: 1;
}
ol, ul {
	list-style: none;
}
blockquote, q {
	quotes: none;
}
blockquote:before, blockquote:after,
q:before, q:after {
	content: '';
	content: none;
}
table {
	border-collapse: collapse;
	border-spacing: 0;
}

/* ========== */
/* From: 'zeta:///zeta.css' */
/* Zeta import: 'zeta:///zeta/z-base/z-base.scss' */
body {
  *font-size: small;
  font: 10.561px sans-serif;
}
button, input, select, textarea {
  font: 99% sans-serif;
}
code, kbd, pre, samp {
  font-family: monospace, sans-serif;
}
body, input, select, textarea {
  color: #444444;
  font-family: Georgia;
}
h1, h2, h3, h4, h5, h6 {
  font-weight: bold;
}
html {
  overflow-y: scroll;
}
:active, :hover {
  outline: none;
}
a, a:active, a:visited {
  color: #607890;
}
a:hover {
  color: #003366;
}
ol, ul {
  margin-left: 1.8em;
}
ol {
  list-style-type: decimal;
}
nav li, nav ul {
  margin: 0;
}
small {
  font-size: 85%;
}
strong, th {
  font-weight: bold;
}
td, td img {
  vertical-align: top;
}
sub, sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
}
sup {
  top: -0.5em;
}
sub {
  bottom: -0.25em;
}
pre {
  padding: 15px;
  white-space: pre;
  white-space: pre-wrap;
  white-space: pre-line;
  word-wrap: break-word;
}
textarea {
  overflow: auto;
}
input[type="radio"] {
  vertical-align: text-bottom;
}
input[type="checkbox"] {
  vertical-align: bottom;
}
.ie7 input[type="checkbox"] {
  vertical-align: baseline;
}
.ie6 input {
  vertical-align: text-bottom;
}
button, input[type="button"], input[type="image"],
input[type="submit"], label {
  cursor: pointer;
}
button, input, select, textarea {
  margin: 0;
}
input:invalid, textarea:invalid {
  border-radius: 1px;
  -moz-box-shadow: 0px 0px 5px #ff0000;
  -webkit-box-shadow: 0px 0px 5px #ff0000;
  box-shadow: 0px 0px 5px #ff0000;
}
.no-boxshadow input:invalid, .no-boxshadow textarea:invalid {
  background-color: #ff0000;
}
::-moz-selection {
  background: #ff5e99;
  color: #ffffff;
  text-shadow: none;
}
::selection {
  background: #ff5e99;
  color: #ffffff;
  text-shadow: none;
}
button {
  width: auto;
  overflow: visible;
}

/* ========== */
/* From: 'zeta:///zeta.css' */
/* Zeta import: 'zeta:///zeta/z-typography/z-typography.css' */
h1 {
	font-size: 3em;
	line-height: 1;
	margin-bottom: 0.5em}

h2 {
	font-size: 2em;
	margin-bottom: 0.75em}

h3 {
	font-size: 1.5em;
	line-height: 1;
	margin-bottom: 1em}

h4 {
	font-size: 1.2em;
	line-height: 1.25;
	margin-bottom: 1.25em}

h5 {
	font-size: 1em;
	font-weight: bold;
	margin-bottom: 1.5em}

h6 {
	font-size: 1em;
	font-weight: bold}

h1 img, h2 img, h3 img, h4 img, h5 img, h6 img {
	margin: 0}

p {
	margin: 0 0 1.5em}

blockquote {
	color: #666;
	font-style: italic;
	margin: 1.5em}

strong, dfn {
	font-weight: bold}

em, dfn {
	font-style: italic}

sup, sub {
	line-height: 0}

abbr, acronym {
	border-bottom: 1px dotted #666}

address {
	font-style: italic;
	margin: 0 0 1.5em}

/* ========== */
/* From: 'zeta:///zeta.css' */
/* Zeta import: 'zeta:///zeta/z-grid/z-grid.scss' */
.z-grid-1 {
  width: 60px;
}
.z-grid-2 {
  width: 140px;
}
.z-grid-3 {
  width: 220px;
}
.z-grid-4 {
  width: 300px;
}
.z-grid-5 {
  width: 380px;
}
.z-grid-6 {
  width: 460px;
}
.z-grid-7 {
  width: 540px;
}
.z-grid-8 {
  width: 620px;
}
.z-grid-9 {
  width: 700px;
}
.z-grid-10 {
  width: 780px;
}
.z-grid-11 {
  width: 860px;
}
.z-grid-12 {
  width: 940px;
}
.z-grid_row {
  width: 960px;
  margin: 0 auto;
  overflow: hidden;
  zoom: 1;
}
.z-grid_column {
  margin: 0 10px;
  display: inline;
  float: left;
  overflow: hidden;
  zoom: 1;
}
.z-grid_row .z-grid_row {
  margin: 0 -10px;
  width: auto;
  display: inline-block;
}

/* ========== */
/* From: '/home/klen/Projects/zeta-library/zetalibrary/tests/zeta/main.css' */
/* Zeta import: 'zeta:///zeta.css' */
/* Zeta is a static framework.
Version 0.1
https://github.com/klen/zeta-libs */

/* ========== */
/* From: '/home/klen/Projects/zeta-library/zetalibrary/tests/zeta/main.css' */
/* Zeta import: '/home/klen/Projects/zeta-library/zetalibrary/tests/zeta/test_helpers.scss' */
.test {
  overflow: hidden;
  zoom: 1;
  display: block;
  text-indent: -999em;
  overflow: hidden;
  background-repeat: no-repeat;
  text-align: left;
  direction: ltr;
  display: inline;
  float: left;
}
.test_center {
  display: block;
  margin-left: auto;
  margin-right: auto;
}
.test_center_round {
  border-radius: 3px 3px;
  -moz-border-radius: 3px 3px;
  -webkit-border-radius: 3px 3px;
  -moz-box-shadow: 4px 3px 2px 1px rgba(10, 10, 10, 0.45);
  -webkit-box-shadow: 4px 3px 2px 1px rgba(10, 10, 10, 0.45);
  box-shadow: 4px 3px 2px 1px rgba(10, 10, 10, 0.45);
}


