// ==========
// From: '/home/klen/Projects/zeta-library/zetalibrary/tests/custom/custom.js'
// Zeta import: '/home/klen/Projects/zeta-library/zetalibrary/tests/custom/fake.js'
function fake () {
    return null;
}


