/* ========== */
/* Zeta import: '/home/klen/Projects/zeta-library/zetalibrary/tests/libs/compass.scss' */
a, abbr, acronym, address, applet, article, aside, audio, b, big,
blockquote, body, canvas, caption, center, cite, code, dd, del,
details, dfn, div, dl, dt, em, embed, fieldset, figcaption, figure,
footer, form, h1, h2, h3, h4, h5, h6, header, hgroup, html, i, iframe,
img, ins, kbd, label, legend, li, mark, menu, nav, object, ol, output,
p, pre, q, ruby, s, samp, section, small, span, strike, strong, sub,
summary, sup, table, tbody, td, tfoot, th, thead, time, tr, tt, u, ul,
var, video {
  margin: 0;
  padding: 0;
  border: 0;
  font-size: 100%;
  font: inherit;
  vertical-align: baseline;
}
body {
  line-height: 1;
}
ol, ul {
  list-style: none;
}
table {
  border-collapse: collapse;
  border-spacing: 0;
}
caption, td, th {
  text-align: left;
  font-weight: normal;
  vertical-align: middle;
}
blockquote, q {
  quotes: none;
}
blockquote:after, blockquote:before, q:after, q:before {
  content: "";
  content: none;
}
a img {
  border: none;
}
elements-of-type(html5-block) {
  display: block;
}
.test {
  color: #0000ff;
  background-image: -webkit-gradient(linear, center top, center bottom, color-stop(0,
    #ffffff), color-stop(1, #000000));
  background-image: -moz-linear-gradient(center top, #ffffff 0, #000000 1);
  background-image: linear-gradient(center top, #ffffff 0, #000000 1);
}


